---
name: Feature Request
about: Suggest an idea for the project. (Please search exisiting issues before submitting. Also see CONTRIBUTING.md.)
title: ""
labels: enhancement
assignees: ""
---


## Description

<!--
    Describe the functionality you would like to see added the project.
    Please be as clear and concise as possible.
-->

## Solution

<!--
    Describe what a possible solution would look and/or act like.
-->

## Additional Context

<!--
    Append any additional context regarding the request here.
    Screenshots are always welcome!
-->
